% a demo
% do inference for a network whose structure is stored in A_p38_39.mat

clear
clc
warning off

% add the path that contains all CCELL codes
addpath('../CCELL');
% add the path that contain Bayesian compressive sensing package
addpath('../CCELL/SB2_Release_200');

%parameter settings
T1 = 5;% number of time points in each perturbation
ss = 300;% number of species in the network
os = ss/2;% number of combined measurements
genNewC = 0;% if ==1,then Low-density parity-check code will generate new C
noiseR = 0.0001;% assumed variance of measurement noise
noiseQ = 0.0001;% assumed variance of process noise
N_per = 6; % number of perturbations
A_name = 'A_p38_39.mat';% the network model to be investigated
num0 = 39;% number of non-zero entries in transition matrix
T = N_per*T1;% total number of time points

%% network inference
%load the transition matrix A
A_i = load(A_name);
Sname = fieldnames(A_i);
A_path = A_i.(Sname{1});
%generate the whole transition matrix with some rows having only one
%non-zero entry corresponding to time-invariant species
A_whole = eye(ss);
A_whole(1:num0,1:num0) = A_path;
A = A_whole;
%call pathway inference program to get results
x_all=[];
y_all =[];
[result  x_all y_all]= pathway_inference_benchmark(N_per,A,ss,os,T,T1,genNewC,noiseR,noiseQ,x_all,y_all);

%% results
x = result{1};% real x
A = result{2};% real A
mu_xt = result{3}; % step1: predicted x
A_pred = result{4}; % step2: predicted A
x_error = result{5}; % step1: RMSE of predicted x
A_error = result{6}; % step2: RMSE of predicted A
sel_ind = result{7}; % which row of A is selected in refinement step
A_EBCS_whole = result{8};%step3: refined A
A_EBCS_error = result{9};%step3: RMSE of refined A
A_EBCS_var = result{10};%step3: variance of refined A

disp(strcat('RMSE of predicted x in Step 1 is:',num2str(x_error,3)))
disp(strcat('RMSE of predicted A in Step 2 is:',num2str(A_error,3)))
disp(strcat('RMSE of predicted A in Step 3 is:',num2str(A_EBCS_error,3)))

